@@ -51,18 +51,18 @@ class Api(object):
         >>> api.IncidentListByID(statuspage_id)
         >>> api.IncidentMessage(statuspage_id, message_id)
         >>> api.IncidentSingle(statuspage_id, incident_id)
-        >>> api.IncidentCreate(statuspage_id, infrastructure_affected, incident_name, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", all_infrastructure_affected="0")
-        >>> api.IncidentUpdate(statuspage_id, incident_id, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.IncidentResolve(statuspage_id, incident_id, incident_details, current_status, current_state, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.IncidentCreate(statuspage_id, infrastructure_affected, incident_name, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0", all_infrastructure_affected="0")
+        >>> api.IncidentUpdate(statuspage_id, incident_id, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.IncidentResolve(statuspage_id, incident_id, incident_details, current_status, current_state, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
         >>> api.IncidentDelete(statuspage_id, incident_id)
         >>> api.MaintenanceList(statuspage_id)
         >>> api.MaintenanceListByID(statuspage_id)
         >>> api.MaintenanceMessage(statuspage_id, message_id)
         >>> api.MaintenanceSingle(statuspage_id, maintenance_id)
-        >>> api.MaintenanceSchedule(statuspage_id, infrastructure_affected, maintenance_name, maintenance_details, date_planned_start, time_planned_start, date_planned_end, time_planned_end, automation="0", all_infrastructure_affected="0", maintenance_notify_now="0", maintenance_notify_1_hr="0", maintenance_notify_24_hr="0", maintenance_notify_72_hr="0")
-        >>> api.MaintenanceStart(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.MaintenanceUpdate(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
-        >>> api.MaintenanceFinish(statuspage_id, maintenance_id, maintenance_details, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.MaintenanceSchedule(statuspage_id, infrastructure_affected, maintenance_name, maintenance_details, date_planned_start, time_planned_start, date_planned_end, time_planned_end, message_subject, automation="0", all_infrastructure_affected="0", maintenance_notify_now="0", maintenance_notify_1_hr="0", maintenance_notify_24_hr="0", maintenance_notify_72_hr="0")
+        >>> api.MaintenanceStart(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.MaintenanceUpdate(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
+        >>> api.MaintenanceFinish(statuspage_id, maintenance_id, maintenance_details, message_subject, notify_email="0", notify_sms="0", notify_webhook="0", social="0", irc="0", hipchat="0", slack="0")
         >>> api.MaintenanceDelete(statuspage_id, maintenance_id)
         >>> api.MetricUpdate(statuspage_id, metric_id, day_avg, day_start, day_dates, day_values, week_avg, week_start, week_dates, week_values, month_avg, month_start, month_dates, month_values)
         >>> api.StatusSummary(statuspage_id)
@@ -220,6 +220,7 @@ class Api(object):
                        incident_details,
                        current_status,
                        current_state,
+                       message_subject,
                        notify_email="0",
                        notify_sms="0",
                        notify_webhook="0",
@@ -245,6 +246,8 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
+             message_subject:
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -278,7 +281,8 @@ class Api(object):
             'irc': irc,
             'hipchat': hipchat,
             'slack': slack,
-            'all_infrastructure_affected': all_infrastructure_affected
+            'all_infrastructure_affected': all_infrastructure_affected,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -289,6 +293,7 @@ class Api(object):
                        incident_details,
                        current_status,
                        current_state,
+                       message_subject,
                        notify_email="0",
                        notify_sms="0",
                        notify_webhook="0",
@@ -309,6 +314,8 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
+             message_subject:
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -340,7 +347,8 @@ class Api(object):
             'social': social,
             'irc': irc,
             'hipchat': hipchat,
-            'slack': slack
+            'slack': slack,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -351,6 +359,7 @@ class Api(object):
                         incident_details,
                         current_status,
                         current_state,
+                        message_subject,
                         notify_email="0",
                         notify_sms="0",
                         notify_webhook="0",
@@ -371,6 +380,8 @@ class Api(object):
                The status of the components and containers affected by this incident
              current_state:
                The state of this incident
+             message_subject
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -402,7 +413,8 @@ class Api(object):
             'social': social,
             'irc': irc,
             'hipchat': hipchat,
-            'slack': slack
+            'slack': slack,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -508,6 +520,7 @@ class Api(object):
                             time_planned_start,
                             date_planned_end,
                             time_planned_end,
+                            message_subject,
                             automation="0",
                             all_infrastructure_affected="0",
                             maintenance_notify_now="0",
@@ -533,6 +546,8 @@ class Api(object):
                Date maintenance is expected to end
              time_planned_end:
                Time maintenance is expected to end
+             message_subject:
+               The message subject for email notifications
              automation:
                Automatically start and end the maintenance (default = 0)
              all_infrastructure_affected:
@@ -564,7 +579,8 @@ class Api(object):
             'maintenance_notify_now': maintenance_notify_now,
             'maintenance_notify_1_hr': maintenance_notify_1_hr,
             'maintenance_notify_24_hr': maintenance_notify_24_hr,
-            'maintenance_notify_72_hr': maintenance_notify_72_hr
+            'maintenance_notify_72_hr': maintenance_notify_72_hr,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -573,6 +589,7 @@ class Api(object):
                          statuspage_id,
                          maintenance_id,
                          maintenance_details,
+                         message_subject,
                          notify_email="0",
                          notify_sms="0",
                          notify_webhook="0",
@@ -589,6 +606,8 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
+             message_subject:
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -618,7 +637,8 @@ class Api(object):
             'social': social,
             'irc': irc,
             'hipchat': hipchat,
-            'slack': slack
+            'slack': slack,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -627,6 +647,7 @@ class Api(object):
                           statuspage_id,
                           maintenance_id,
                           maintenance_details,
+                          message_subject,
                           notify_email="0",
                           notify_sms="0",
                           notify_webhook="0",
@@ -643,6 +664,8 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
+             message_subject:
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -672,7 +695,8 @@ class Api(object):
             'social': social,
             'irc': irc,
             'hipchat': hipchat,
-            'slack': slack
+            'slack': slack,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
@@ -681,6 +705,7 @@ class Api(object):
                           statuspage_id,
                           maintenance_id,
                           maintenance_details,
+                          message_subject,
                           notify_email="0",
                           notify_sms="0",
                           notify_webhook="0",
@@ -697,6 +722,8 @@ class Api(object):
                Maintenance ID
              maintenance_details:
                Message describing this maintenance update
+             message_subject:
+               The message subject for email notifications
              notify_email:
                Notify email subscribers (1 = Send notification)
              notify_sms:
@@ -726,7 +753,8 @@ class Api(object):
             'social': social,
             'irc': irc,
             'hipchat': hipchat,
-            'slack': slack
+            'slack': slack,
+            'message_subject': message_subject
         })
         data = json.loads(resp.content.decode('utf-8'))
         return data
